@@ -19,7 +19,7 @@
  *    along with GnuDOS.  If not, see <http://www.gnu.org/licenses/>.
  */    
 #include <stdio.h>
-#include "strings.h"
+#include "console/strings.h"
 
 int main(int argc, char **argv) 
 {
