@@ -219,8 +219,8 @@ void calcCharCarry(int pos);
 int  is_whitespace(char c);
 
 //extern char *strdup(const char *s);    /* string.h */
-//extern int fcloseall (void);    /* stdio.h */
-//extern char *strcasestr (const char *HAYSTACK, const char *NEEDLE);    /* string.h */
+extern int fcloseall (void);    /* stdio.h */
+extern char *strcasestr (const char *HAYSTACK, const char *NEEDLE);    /* string.h */
 //extern int strcasecmp (const char *S1, const char *S2);     /* string.h */
 extern char *copyrightNotice;
 
