@@ -34,11 +34,11 @@ struct dirent **eps;
 int epscount;
 
 #define DIR_RETURN_ERROR()		\
-{					\
+do {					\
     msgBox(strerror(errno), OK, ERROR);	\
-    chdir(oldcwd);                      \
+    if(chdir(oldcwd)) return 0;         \
     return 0;				\
-}
+} while(0)
 
 static int one(const struct dirent *unused) 
 {
