@@ -1,22 +1,22 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: kbd.h
- *    This file is part of mino (Mino).
+ *    This file is part of mino.
  *
- *    mino (Mino) is free software: you can redistribute it and/or modify
+ *    mino is free software: you can redistribute it and/or modify
  *    it under the terms of the GNU General Public License as published by
  *    the Free Software Foundation, either version 3 of the License, or
  *    (at your option) any later version.
  *
- *    mino (Mino) is distributed in the hope that it will be useful,
+ *    mino is distributed in the hope that it will be useful,
  *    but WITHOUT ANY WARRANTY; without even the implied warranty of
  *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *    GNU General Public License for more details.
  *
  *    You should have received a copy of the GNU General Public License
- *    along with mino (Mino).  If not, see <http://www.gnu.org/licenses/>.
+ *    along with mino.  If not, see <http://www.gnu.org/licenses/>.
  */    
 #ifndef __KBD_H
 #define __KBD_H
@@ -28,21 +28,16 @@
        240 - 11110xxx - for U+010000 to U+1FFFFF */
 extern unsigned short mask[]; // = {192, 224, 240};
 
-#ifndef __BOOL_DEFINED_
-#define __BOOL_DEFINED_
-typedef int bool;
-#endif
-
-bool ALT;
-bool CTRL;
-bool SHIFT;
-bool CAPS;
-bool INSERT;
+int ALT;
+int CTRL;
+int SHIFT;
+int CAPS;
+int INSERT;
 
 int initTerminal();
 void restoreTerminal();
 
-bool X_IS_RUNNING;
+int X_IS_RUNNING;
 char *getKey();
 char *getKeyUnderConsole();
 char *getKeyUnderX();
@@ -68,7 +63,6 @@ char *getKeyUnderX();
 #define SHIFT_UP	18
 #define PGUP_KEY	19
 #define PGDOWN_KEY	20
+#define FUNCTION_KEY    21
 
-//the Unicode character returned by getKey()
-extern char uc[5];
 #endif
