@@ -860,9 +860,10 @@ void checkFileExtension(char *open_file_name)
     {
         //check what was the file extension
         ext++;
-        for(int i = 0; i < NUM_MODULES; i++)
+	int i, j;
+        for(i = 0; i < NUM_MODULES; i++)
         {
-            for(int j = 0; j < module[i]->extsCount; j++)
+            for(j = 0; j < module[i]->extsCount; j++)
             {
                 if(strcmp(ext, module[i]->exts[j]) == 0)
                 {
