@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2014, 2015, 2016 (c)
+ *    Copyright 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: screen.c
  *    This file is part of mino.
@@ -23,12 +23,18 @@
 #include <string.h>
 #include <sys/ioctl.h>	//included for terminal size query
 #include "defs.h"
+#include "options.h"
 
 void setScreenColors(int FG, int BG) 
 {
     fprintf(stdout, "\x1b[%d;%dm", FG, BG);	//control sequence to set screen color
 }
 
+void setScreenColorsI(int colorIndex) 
+{
+    fprintf(stdout, "\x1b[%d;%dm", FG_COLOR[colorIndex], BG_COLOR[colorIndex]);
+}
+
 void getScreenSize() 
 {
     struct winsize w;
@@ -44,3 +50,17 @@ void clearScreen()
     fprintf(stdout, "\e[3J\e[1;1H");
     fflush(stdout);
 }
+
+void showCursor()
+{
+  //turn the cursor on
+  printf("\e[?25h");
+  fflush(stdout);
+}
+
+void hideCursor()
+{
+  //turn the cursor off
+  printf("\e[?25l");
+  fflush(stdout);
+}
