@@ -1,6 +1,6 @@
 /* 
  *    Programmed By: Mohammed Isam Mohammed [mohammed_isam1984@yahoo.com]
- *    Copyright 2013, 2014, 2015 (c)
+ *    Copyright 2013, 2014, 2015, 2016, 2017, 2018 (c)
  * 
  *    file: edit.h
  *    This file contains function prototypes and variable declarations
@@ -29,15 +29,17 @@ void copyMarked();
 void pasteMarked();
 void deleteMarked();
 void markAll();
-void unMarkAll();
+void unMarkAll(int activeWindow);
 void clearSelection();
 
 //These functions are NOT called directly, instead they are called
 //by the pasteMarked() function.
-void copyThisFile(char *fileName);
-void copyThisDir(char tmp[], int level);
-void moveThisDir(char tmp[], int level);
-void deleteThisDir(char tmp[], int level);
-void deleteThisFile(char *fileName);
+void copyThisFile(char *fileName, FILE *logfile);
+void copyThisDir(char *tmp, int level, FILE *logfile);
+void moveThisDir(char *tmp, int level, FILE *logfile);
+void deleteThisDir(char *tmp, int level, FILE *logfile);
 
-#endif
\ No newline at end of file
+void editMenu_Find();
+void editMenu_Properties();
+
+#endif
