@@ -140,7 +140,7 @@ void scanThisDir(char *tmp, int level, int showProgress)
             if(z == -1)
             {
                 if(showProgress) showErrorMsgBox(strerror(errno), d);
-                chdir("..");
+                if(chdir("..")) return;
                 return;
             }
       
