@@ -166,6 +166,7 @@ void findFile()
                         /////////////////////////////////////////////
                         if(strchr(findFileName, '*')) 
                         {
+                            int fnlen = strlen(findFileName);
                             i = strchr(findFileName, '*')-findFileName;
                             if(i == 0) 
                             {
@@ -173,9 +174,9 @@ void findFile()
                                 strcpy(middleStr, "\0");
                                 strcpy(endStr, findFileName+1);
                             }
-                            else if(i == strlen(findFileName)-1) 
+                            else if(i == fnlen-1) 
                             {
-                                strncpy(startStr, findFileName, strlen(findFileName)-1);
+                                strncpy(startStr, findFileName, fnlen-1);
                                 strcpy(middleStr, "\0");
                                 strcpy(endStr, "*");
                             }
@@ -183,7 +184,7 @@ void findFile()
                             {
                                 strncpy(startStr, findFileName, i);
                                 strcpy(middleStr, "*");
-                                strcpy(endStr, findFileName+strlen(findFileName)-i);
+                                strcpy(endStr, findFileName+fnlen-i);
                             }
                             /////////////////////////////////////////////
                         }
